@@ -1,4 +1,4 @@
-# $Id: mdnconf.tcl,v 1.12 2001/02/02 00:49:51 ishisone Exp $
+# $Id: mdnconf.tcl,v 1.15 2001/04/20 02:31:18 ishisone Exp $
 #
 # mdnconf.tcl - configure mDN Wrapper
 #
@@ -65,34 +65,26 @@ global  configFile configBack
 global  registryKey registryEnc registryDef
 global  filesCpy filesRen filesDel
 
+# mDNkit version
+set version	"2.1"
+
 set configFile  "mdnconf.lst"   ;# list of wrapped program
 set configBack  "mdnconf.bak"   ;# backup of previous data
 
-set serverKey   "HKEY_LOCAL_MACHINE\\Software\\JPNIC\\MDN"
-set serverEnc   "Encoding"
-set serverDef   "RACE"
-set serverLogLevel "LogLevel"
-set serverLogLevelDef 0
-set serverLogLevelNone -1
-set serverLogFile "LogFile"
-set serverLogFileDef {C:\mdn_wrapper.log}
+set serverKey		"HKEY_LOCAL_MACHINE\\Software\\JPNIC\\MDN"
+set serverLogLevel	LogLevel
+set serverLogLevelDef	-1
+set serverLogLevelNone	-1
+set serverLogFile	LogFile
+set serverLogFileDef	{C:\mdn_wrapper.log}
+set serverConfFile	ConfFile
 
-set perprogKey  "HKEY_LOCAL_MACHINE\\Software\\JPNIC\\MDN\\PerProg\\"
-set perprogEnc  "Encoding"
-set perprogDef  "Default"
+set perprogKey		"HKEY_LOCAL_MACHINE\\Software\\JPNIC\\MDN\\PerProg\\"
+set perprogEnc		Encoding
+set perprogDef		Default
 
-set logFileNameDef mdn_wrapper.log
-
-set normalizerList [list \
-    ascii-lowercase ascii-uppercase \
-    unicode-lowercase unicode-uppercase \
-    unicode-form-c unicode-form-kc \
-    ja-kana-fullwidth ja-alnum-halfwidth ja-compose-voiced-sound \
-    ja-minus-hack ja-delimiter-hack]
-
-set normalizerDef [list \
-    ja-kana-fullwidth ja-alnum-halfwidth ja-compose-voiced-sound \
-    unicode-lowercase unicode-form-kc]
+set logFileNameDef	mdn_wrapper.log
+set confFileNameDef	mdn.conf
 
 set filesCpy11 { "jpnicmdn.dll" "iconv.dll" "wsock32.dll" }
 set filesCpy20 { "jpnicmdn.dll" "iconv.dll" "wsock32.dll" "ws2_32.dll" }
@@ -294,14 +286,27 @@ proc regSetLogFile {file} {
     regSetValue $serverKey $serverLogFile [file nativename $file]
 }
 
-proc regGetNormalize {} {
-    global serverKey normalizerDef
-    regGetValue $serverKey Normalize $normalizerDef
+proc regGetConfFile {} {
+    global serverKey serverConfFile
+    set file [regGetValue $serverKey $serverConfFile {}]
+    if {[string compare $file {}] == 0} {
+	return {}
+    }
+    if {[catch {file attributes $file -longname} lfile]} {
+	# Maybe $file doesn't exist (yet).  Get the longname of
+	# directory portion.
+	set dir [file dirname $file]
+	if {[catch {file attributes $dir -longname} ldir]} {
+	    set ldir $dir
+	}
+	set lfile [file join $ldir [file tail $file]]
+    }
+    file nativename $lfile
 }
 
-proc regSetNormalize {list} {
-    global serverKey
-    regSetValue $serverKey Normalize [join $list] sz
+proc regSetConfFile {file} {
+    global serverKey serverConfFile
+    regSetValue $serverKey $serverConfFile [file nativename $file]
 }
 
 proc regGetWhere {} {
@@ -314,16 +319,6 @@ proc regSetWhere {where} {
     regSetValue $serverKey Where $where dword
 }
 
-proc regGetDNSEncoding {} {
-    global serverKey serverEnc serverDef
-    regGetValue $serverKey $serverEnc $serverDef
-}
-
-proc regSetDNSEncoding {encoding} {
-    global serverKey serverEnc
-    regSetValue $serverKey $serverEnc $encoding sz
-}
-
 proc regGetValue {key name default} {
     if {![isWindows]} {
 	puts "--regGetValue $key $name"
@@ -353,6 +348,7 @@ proc regSetValue {key name value {type sz}} {
     }
     return 0
 }
+
 ########################################################################
 #
 # install / uninstall DLL s
@@ -699,7 +695,7 @@ proc confLog {pw} {
     button $w.ld_v.b -text "Browse.." -command [list selectLog $top $w.ld_v.e]
     pack $w.ld_v.b -side right -fill y -padx 6
     pack $w.ld_v.e -side left -fill both -expand yes
-    label $w.lo_l -text "Log Operation:"
+    #label $w.lo_l -text "Log Operation:"
     frame $w.lo_v
     button $w.lo_v.show -text "View" -command [list showLog $top]
     button $w.lo_v.delete -text "Delete" -command [list deleteLog $top]
@@ -707,7 +703,7 @@ proc confLog {pw} {
 
     grid $w.lv_l -row 0 -column 0 -sticky e -padx 4
     grid $w.ld_l -row 1 -column 0 -sticky e -padx 4
-    grid $w.lo_l -row 2 -column 0 -sticky e -padx 4
+    #grid $w.lo_l -row 2 -column 0 -sticky e -padx 4
     grid $w.lv_v -row 0 -column 1 -sticky w -padx 4 -pady 4
     grid $w.ld_v -row 1 -column 1 -sticky we -padx 4 -pady 4
     grid $w.lo_v -row 2 -column 1 -sticky w -padx 4 -pady 4
@@ -759,7 +755,7 @@ proc selectLog {top e} {
 proc showLog {top} {
     global _logFile
     if {[catch {exec notepad.exe $_logFile &} r]} {
-	confErrorDialog $top "Cannot execute nodepad"
+	confErrorDialog $top "Cannot execute notepad"
     }
 }
 
@@ -786,12 +782,11 @@ proc advancedConf {pw} {
     toplevel $top
     wm title $top "mDN Wrapper - Advanced Configuration"
 
-    global _mdnOperation _mdnDNSEncoding
+    global _mdnOperation _confFile
     set _mdnOperation [regGetWhere]
-    set _mdnDNSEncoding [regGetDNSEncoding]
-    set normSchemes [regGetNormalize]
+    set _confFile [regGetConfFile]
 
-    foreach f {f1 f2 f3 f4} {
+    foreach f {f1 f2 f3} {
 	frame $top.$f -bd 1 -relief raised
 	pack $top.$f -side top -fill x
     }
@@ -813,95 +808,55 @@ proc advancedConf {pw} {
     pack $w -side top -fill both -padx 20 -pady 10
 
     set f $top.f2
-    label $f.lbl -text Normalization
+    label $f.lbl -text {MDN Configuration}
     pack $f.lbl -side top -fill x -pady 6
 
     set w $f.f
     frame $w
     pack $w -side top -fill both -padx 10 -pady 6
-    label $w.l1 -text Selected
-    listbox $w.lb1 -width 25 -height 8 -bd 2 -relief sunken \
-	    -yscrollcommand [list $w.sb1 set] -exportselection no
-    set lb $w.lb1
-    scrollbar $w.sb1 -orient vertical -bd 2 -relief sunken \
-	    -command [list $w.lb1 yview]
-
-    label $w.l2 -text Available
-    listbox $w.lb2 -width 25 -height 8 -bd 2 -relief sunken \
-	    -yscrollcommand [list $w.sb2 set] -exportselection no
-    scrollbar $w.sb2 -orient vertical -bd 2 -relief sunken \
-	    -command [list $w.lb2 yview]
-
-    bind $w.lb1 <Delete> [list normalizerAction remove $w.lb1 $w.lb2]
-    bind $w.lb1 <BackSpace> [list normalizerAction remove $w.lb1 $w.lb2]
-    bind $w.lb2 <Double-ButtonPress-1> \
-	    [list normalizerAction add $w.lb1 $w.lb2]
-    bind $w.lb2 <Return> \
-	    [list normalizerAction add $w.lb1 $w.lb2]
-
-    eval $w.lb1 insert end $normSchemes
-    eval $w.lb2 insert end $normalizerList
-
-    frame $w.sp -width 10 -height 1 -bd 0
-
-    frame $w.pnl
-    foreach {btn text} {add Add remove Remove clear Clear reset Reset} {
-	button $w.$btn -text $text \
-		-command [list normalizerAction $btn $w.lb1 $w.lb2]
-	pack $w.$btn -in $w.pnl -side left -padx 8 -pady 8
-    }
-
-    grid $w.l1 - $w.sp $w.l2 -
-    grid $w.lb1 $w.sb1 x $w.lb2 $w.sb2 -sticky ns
-    grid $w.pnl - - - -
+    label $w.l1 -text {Config File:}
+    #label $w.l2 -text {Config Operation:}
+    entry $w.e -width 40 -textvariable _confFile
+    focus $w.e
+    button $w.br -text "Browse.." -command [list selectConf $top $w.e]
+    button $w.b -text Edit -command [list editConf $top]
+    grid $w.l1 -row 0 -column 0 -sticky e -padx 4
+    #grid $w.l2 -row 1 -column 0 -sticky e -padx 4
+    grid $w.e -row 0 -column 1 -sticky we -padx 4 -pady 4
+    grid $w.b -row 1 -column 1 -sticky w -padx 4 -pady 4
+    grid $w.br -row 0 -column 2 -sticky w -padx 4 -pady 4
 
     set w $top.f3
-    label $w.t -text {DNS Encoding}
-    frame $w.f
-    label $w.l -text Encoding:
-    entry $w.e -width 30 -textvariable _mdnDNSEncoding
-    pack $w.t -side top -fill x -pady 6
-    pack $w.f -side top -fill x -padx 10 -pady 8
-    pack $w.l -side left -padx 4 -in $w.f
-    pack $w.e -side left -padx 4 -in $w.f
-
-    set w $top.f4
-    button $w.ok -text "OK" -command [list advConf $top $lb]
+    button $w.ok -text "OK" -command [list advConf $top]
     button $w.cancel -text "Cancel" -command [list destroy $top]
     pack $w.cancel -side right -padx 12 -pady 8
     pack $w.ok -side right -padx 12 -pady 8
 }
 
-proc normalizerAction {action lb1 lb2} {
-    global normalizerDef
-
-    switch -- $action {
-	add {
-	    foreach idx [$lb2 curselection] {
-		$lb1 insert end [$lb2 get $idx]
-	    }
-	}
-	remove {
-	    foreach idx [lsort -integer -decreasing [$lb1 curselection]] {
-		$lb1 delete $idx
-	    }
-	}
-	clear {
-	    $lb1 delete 0 end
-	}
-	reset {
-	    $lb1 delete 0 end
-	    eval $lb1 insert end $normalizerDef
-	}
+proc editConf {top} {
+    global _confFile
+    if {[catch {exec notepad.exe $_confFile &} r]} {
+	confErrorDialog $top "Cannot execute notepad"
     }
 }
 
-proc advConf {top lb} {
-    global _mdnOperation _mdnDNSEncoding
+proc selectConf {top e} {
+    global confFileNameDef
+    set file [tk_getOpenFile -title {mDN Wrapper Config File Selection} \
+	    -defaultextension .conf \
+	    -filetypes {{{Config Files} .conf} {{All Files} *}} \
+	    -initialfile $confFileNameDef \
+	    -parent $top]
+    if {[string compare $file {}]} {
+	$e delete 0 end
+	$e insert insert $file
+    }
+}
+
+proc advConf {top} {
+    global _mdnOperation _confFile
     regSetWhere $_mdnOperation
-    set l [list]
-    regSetNormalize [$lb get 0 end]
-    regSetDNSEncoding $_mdnDNSEncoding
+    regSetConfFile $_confFile
     destroy $top
 }
 
@@ -928,6 +883,10 @@ proc isWindows {} {
 wm title    . "mDN Wrapper - Configuration"
 wm iconname . "mDN Wrapper - Configuration"
 
+
+label .title -bd 1 -relief raised -pady 5 \
+	-text "mDN Wrapper Configuration Program version $version"
+
 frame .left -bd 1 -relief raised
 frame .right -bd 1 -relief raised
 
@@ -968,6 +927,7 @@ pack .btn.exit   -side bottom -fill x -pady 4
 pack .lst -in .left -padx 4 -pady 4 -fill both -expand on
 pack .btn -in .right -padx 6 -pady 4 -fill both -expand on
 
+pack .title -side top -fill x
 pack .right -side right -fill y
 pack .left -side left -fill y -expand on
 
